pub struct OneTestPerProcessGuard(());Expand description
When this guard is active, enforces that there is only a single test running in the process at any one time. If there are multiple processes, creating the guard hard terminates the process.
Tuple Fields
0: ()Implementations