pub async fn initialize_adapter(
adapter_report: Option<&AdapterReport>,
params: &TestParameters,
) -> Option<(Instance, Adapter, Option<SurfaceGuard>)>Expand description
Initialize a wgpu adapter, using the given adapter report to match the adapter.
Returns None if the adapter from the report is not returned by enumerate_adapters due to InstanceFlags::STRICT_WEBGPU_COMPLIANCE being set.